<?php
/**
 * @version		3.0
 * @package		Joomla
 * @subpackage	Payment Form
 * @author  Tuan Pham Ngoc
 * @copyright	Copyright (C) 2010 Ossolution Team
 * @license		GNU/GPL, see LICENSE.php
 */
// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die ;
/**
 * Payment Form Component Field Model
 *
 * @package		Joomla
 * @subpackage	Payment Form
 * @since 1.5
 */
class PmFormModelField extends JModelLegacy
{
	/**
	 * Field id
	 *
	 * @var int
	 */
	var $_id = null;
	/**
	 * Field data
	 *
	 * @var array
	 */
	var $_data = null;

	/**
	 * Constructor
	 *
	 * @since 1.5
	 */
	function __construct()
	{
		parent::__construct();
		$array = JRequest::getVar('cid', array(0), '', 'array');
		$edit	= JRequest::getVar('edit',true);
		if($edit)
			$this->setId((int)$array[0]);
	}
	/**
	 * Method to set the field identifier
	 *
	 * @access	public
	 * @param	int field identifier
	 */
	function setId($id)
	{
		// Set field id and wipe data
		$this->_id		= $id;
		$this->_data	= null;
	}
	/**
	 * Method to get a field
	 *
	 * @since 1.5
	 */
	function &getData()
	{
		if (empty($this->_data)) {
			if ($this->_id)
				$this->_loadData();
			else 
				$this->_initData();	
		}					
		return $this->_data;
	}
	/**
	 * Method to store a field
	 *
	 * @access	public
	 * @return	boolean	True on success
	 * @since	1.5
	 */
	function store(&$data)
	{		
		$j3 = version_compare(JVERSION, '3.0', 'ge') ? true : false ;
		$row = & $this->getTable('PmForm', 'Field');	
		if ($data['id'])
		    $row->load($data['id']);
		if ($row->is_core) {
		    $ignore = array('name', 'field_type', 'fee_field');
		} else {
		    $ignore = array();
		}    
		if (!$row->bind($data, $ignore)) {
			$this->setError($this->_db->getErrorMsg());
			return false;
		}	
		$isNew = false ;
		if (!$row->id) {
			$isNew = true ;
			$sql = 'SELECT MAX(ordering) + 1 AS ordering FROM #__pf_fields';
			$this->_db->setQuery($sql) ;
			$row->ordering = $this->_db->loadResult();	
			if ($row->ordering == 0)
				$row->ordering = 1 ;
		}
		if (!isset($data['form_id']) || $data['form_id'][0] == -1 || in_array($row->name, array('first_name', 'email', 'amount'))) {
			$row->form_id = -1 ;
		} else {
			$row->form_id = 1 ;
		}			
		if (!$row->store()) {
			$this->setError($this->_db->getErrorMsg());
			return false;
		}			
		//Insert this into database table		
		if ($row->form_id != - 1) {
			$formIds = JRequest::getVar('form_id', array(), 'post') ;
			$sql = 'DELETE FROM #__pf_form_fields WHERE field_id='.$row->id.' AND form_id NOT IN ('.implode(',', $formIds).')';
			$this->_db->setQuery($sql);
			$this->_db->query() ;            		
			for ($i = 0 , $n = count($formIds) ; $i < $n ; $i++) {
				$formId = $formIds[$i] ;												
				$sql = "SELECT COUNT(id) FROM #__pf_form_fields WHERE field_id=$row->id AND form_id=".$formId;
				$this->_db->setQuery($sql) ;
				$total = $this->_db->loadResult() ;
                if (!$total) {
                     //Add this field to bottom of form
                     $sql = 'SELECT MAX(ordering) FROM #__pf_form_fields WHERE form_id='.$formId;
                     $this->_db->setQuery($sql) ;
                     $ordering = (int) $this->_db->loadResult() + 1 ;
                    
                    $sql = 'INSERT INTO #__pf_form_fields(form_id, field_id, required, published, ordering)'
                    	."VALUES($formId, $row->id, 0, 1, $ordering)"                                        
                    ; 
                    $this->_db->setQuery($sql) ;
                    $this->_db->query() ;
                }												
			}								
		} else {
		    //Fields is assigned to al forms, insert data into form field settings table
		    $sql = 'SELECT id FROM #__pf_forms WHERE published=1';
		    $this->_db->setQuery($sql);
		    if ($j3) {
		    	$formIds = $this->_db->loadColumn() ;
		    } else {
		    	$formIds = $this->_db->loadResultArray() ;
		    } 		    		    
		    for ($i = 0 , $n = count($formIds) ; $i < $n ; $i++) {
				$formId = $formIds[$i] ;						
				//Check to see whether this form added to setting tables or not
				$sql = "SELECT COUNT(id) FROM #__pf_form_fields WHERE field_id=$row->id AND form_id=".$formId;
				$this->_db->setQuery($sql) ;
				$total = $this->_db->loadResult() ;
                if (!$total) {
                     //Add this field to bottom of form
                     $sql = 'SELECT MAX(ordering) FROM #__pf_form_fields WHERE form_id='.$formId;
                     $this->_db->setQuery($sql) ;
                     $ordering = (int) $this->_db->loadResult() + 1 ;                    
                    $sql = 'INSERT INTO #__pf_form_fields(form_id, field_id, required, published, ordering)'
                    	."VALUES($formId, $row->id, 0, 1, $ordering)"                                        
                    ; 
                    $this->_db->setQuery($sql) ;
                    $this->_db->query() ;
                }												
			}			    		    
		}
		JRequest::setVar('id', $row->id);				
		return true;
	}
	/**
	 * Init field data
	 *
	 */
	function _initData() {
		$field = new stdClass ;		
		$field->id = null ;		
		$field->form_id = 0 ;
		$field->name = null ;
		$field->title = null ;
		$field->field_type = null ;
		$field->description = null ;				
		$field->required = null ;
		$field->values = null ;
		$field->default_values = null ;
		$field->fee_field = 0 ;
		$field->fee_values = null ;
		$field->rows = null ;
		$field->cols = null ;
		$field->size = null ;
		$field->css_class = "inputbox" ;				
		$field->published = 1 ;		
		$field->datatype_validation = 0 ;
		$field->fee_formula = null ;
		$field->field_mapping = null ;
		$field->is_core = 0 ;
		$this->_data = $field ;
	}
	/**
	 * Load field data
	 *
	 */
	function _loadData() {
		$sql = 'SELECT * FROM #__pf_fields WHERE id='.$this->_id;
		$this->_db->setQuery($sql);			
		$this->_data = $this->_db->loadObject();
	}
	/**
	 * Method to remove  fields
	 *
	 * @access	public
	 * @return	boolean	True on success
	 * @since	1.5
	 */
	function delete($cid = array())
	{		
		if (count( $cid ))
		{
			$sql = 'SELECT id FROM #__pf_fields WHERE is_core = 1 ';
			$this->_db->setQuery($sql) ;
			if (version_compare(JVERSION, '3.0', 'ge'))
				$coreIds = $this->_db->loadColumn();
			else				
				$coreIds = $this->_db->loadResultArray();
			for ($i = 0 , $n = count($cid) ; $i < $n ; $i++) {
				$id = $cid[$i] ;
				if (!in_array($id, $coreIds)) {
					//Delete data from field values table
					$sql = 'DELETE FROM #__pf_field_value WHERE field_id = '.$id ;
					$this->_db->setQuery($sql);
					if (!$this->_db->query())
						return false ;
					$sql = 'DELETE FROM #__pf_fields WHERE id = '.$id ;
					$this->_db->setQuery($sql);
					if (!$this->_db->query())
						return false;											
					$sql = 'DELETE FROM #__pf_form_fields WHERE field_id = '.$id ;
					$this->_db->setQuery($sql);
					if (!$this->_db->query())
						return false;											
				}
			}								
		}
		return true;
	}
	/**
	 * Publish or unpublish a field
	 *
	 * @param int $id
	 * @param int $state
	 */
	function publish($cid, $state) {
		$cids = implode(',', $cid) ;		
		$sql = 'UPDATE #__pf_fields SET published='.$state. ' WHERE id IN ('.$cids .' ) AND name NOT IN("first_name", "email", "amount")';
		$this->_db->setQuery($sql);
		if ($this->_db->query())
			return true ;
		else 
			return false ;					
	}
	/**
	 * Change require status
	 *
	 * @param array $cid
	 * @param int $state
	 * @return boolean
	 */
	function required($cid, $state) {
		$cids = implode(',', $cid) ;		
		$sql = 'UPDATE #__pf_fields SET required='.$state. ' WHERE id IN ('.$cids .' )';
		$this->_db->setQuery($sql);
		if ($this->_db->query())
			return true ;
		else 
			return false ;					
	}
	/**
	 * Save the order of fields
	 *
	 * @param array $cid
	 * @param array $order
	 */
	function saveOrder($cid, $order) {
		$row = JTable::getInstance('PmForm', 'Field');				
		for( $i=0; $i < count($cid); $i++ )
		{
			$row->load( (int) $cid[$i] );						
			if ($row->ordering != $order[$i])
			{
				$row->ordering = $order[$i];
				if (!$row->store()) {
					$this->setError($this->_db->getErrorMsg());
					return false;
				}
			}
		}		
		return true;	
	}	
	/**
	 * Change ordering of an album
	 *
	 */
	function move($direction) {
		$row = JTable::getInstance('PmForm', 'Field');
		$row->load($this->_id);		
		if (!$row->move( $direction, ' published >= 0 ')) {
			$this->setError($this->_db->getErrorMsg());
			return false;
		}
		$row->reorder();
		return true;
	}
	/**
	 * Copy a field
	 *
	 * @param int $id
	 */	
	function copy($id) {
		$rowOld = JTable::getInstance('pmform', 'Field');
		$rowOld->load($id) ;
		if ($rowOld->is_core) {
		    $app = JFactory::getApplication('admin');
		    $app->enqueueMessage('A core field could not be copied', 'error') ;
		    $app->redirect('index.php?option=com_pmform&view=fields');		    
		    return false ;
		}
		$row = JTable::getInstance('pmform', 'Field');
		$data = JArrayHelper::fromObject($rowOld) ; 
		$row->bind($data) ;
		$row->id = 0 ;
		$row->title = 'Copy of '.$row->title ;
		$row->store() ;
		$fieldId = $row->id ;
		$sql = "INSERT INTO #__pf_form_fields(form_id, field_id, required, published, ordering) 
				SELECT form_id, $fieldId, required, published, ordering FROM #__pf_form_fields WHERE field_id=$id
			   "				
		;
		$this->_db->setQuery($sql) ;
		$this->_db->query();				
		
		return $row->id ;	
	}	
}