<?php
/**
 * @version		3.0
 * @package		Joomla
 * @subpackage	Payment Form
 * @author  Tuan Pham Ngoc
 * @copyright	Copyright (C) 2010 Ossolution Team
 * @license		GNU/GPL, see LICENSE.php
 */
// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die ;
/**
 * Payment Form Component Form Model
 *
 * @package		Joomla
 * @subpackage	Payment Form
 * @since 1.5
 */
class PmFormModelForm extends JModelLegacy
{
	/**
	 * Form id
	 *
	 * @var int
	 */
	var $_id = null;
	/**
	 * Form data
	 *
	 * @var array
	 */
	var $_data = null;

	/**
	 * Constructor
	 *
	 * @since 1.5
	 */
	function __construct()
	{
		parent::__construct();
		$array = JRequest::getVar('cid', array(0), '', 'array');
		$edit	= JRequest::getVar('edit',true);
		if($edit)
			$this->setId((int)$array[0]);
	}
	/**
	 * Method to set the form identifier
	 *
	 * @access	public
	 * @param	int form identifier
	 */
	function setId($id)
	{
		// Set campaign id and wipe data
		$this->_id		= $id;
		$this->_data	= null;
	}
	/**
	 * Method to get a campaign
	 *
	 * @since 1.5
	 */
	function &getData()
	{
		if (empty($this->_data)) {
			if ($this->_id)
				$this->_loadData();
			else 
				$this->_initData();	
		}					
		return $this->_data;
	}
	/**
	 * Method to get list of fields assigned to this form
	 * 
	 */
	function getFields() {	   
	   $db = JFactory::getDbo() ;
	   if (!$this->_id) {
	       $sql = 'SELECT * FROM #__pf_fields WHERE published=1 AND (is_core=1 OR form_id=-1) ORDER BY id, title ';
	       $db->setQuery($sql) ;
	       $rowFields = $db->loadObjectList() ;
	       for ($i = 0 , $n = count($rowFields) ; $i < $n ; $i++) {
	           $rowField = $rowFields[$i] ;
	           $rowField->ordering = $i + 1 ;
	           $rowField->required = 1 ;	           	          
	       }    
	   } else {
	       //Get all fields assigned to this form
	       $sql = 'SELECT a.*, b.ordering, b.required, b.published FROM #__pf_fields AS a '
	       	.    ' INNER JOIN #__pf_form_fields as b '
	       	.	 ' ON a.id = b.field_id '
	       	.    ' WHERE b.form_id='.$this->_id
	       	.	 ' ORDER BY b.ordering '	       	       
	       ;
	       $db->setQuery($sql) ;
	       $rowFields = $db->loadObjectList() ;	       
	   }
	   return $rowFields ; 
	}	
	/**
	 * Method to store a campaign
	 *
	 * @access	public
	 * @return	boolean	True on success
	 * @since	1.5
	 */
	function store(&$data)
	{		
		$row = & $this->getTable('pmform', 'Form');			
		if (!$row->bind($data, array('payment_methods'))) {
			$this->setError($this->_db->getErrorMsg());
			return false;
		}
		if (!$row->publish_up) {
			$row->publish_up = '0000-00-00 00:00:00';		
		}
		if (!$row->publish_down) {
			$row->publish_down = '0000-00-00 00:00:00';
		}
		if (!$row->late_payment_date) {
			$row->late_payment_date = '0000-00-00 00:00:00';
		}
		if (!$row->id) {
			$sql = 'SELECT MAX(ordering) FROM #__pf_forms ' ;
			$this->_db->setQuery($sql) ;
			$row->ordering = $this->_db->loadResult() + 1 ;				
		}
				
		$row->payment_methods = implode(',', $data['payment_methods']);
		
		if (!$row->store()) {
			$this->setError($this->_db->getErrorMsg());
			return false;
		}

		//Store form fields setting
		$db = JFactory::getDbo() ;
		$sql = 'DELETE FROM #__pf_form_fields WHERE form_id='.$row->id;
		$db->setQuery($sql) ;
		$db->query();
		$fields = JRequest::getVar('fields', array(), 'post') ;
		foreach ($fields as $fieldId) {
		    $published = JRequest::getInt('published_'.$fieldId, 0, 'post') ;
		    $required = JRequest::getInt('required_'.$fieldId, 0, 'post') ;
		    $ordering = JRequest::getInt('ordering_'.$fieldId, 0, 'post') ;
		    //First name and email are always required fields		    
		    if (in_array($fieldId, array(1, 12))) {
		         $published = 1 ;
		         $required = 1 ;   
		    }		        		    		   
		    $sql = "INSERT INTO #__pf_form_fields (form_id, field_id, required, published, ordering) VALUES($row->id, $fieldId, $required, $published, $ordering)" ;
		    $db->setQuery($sql) ;
		    $db->query();		    		    		   		    		    
		}	
		//Re-ordering the ordering field using sequence number
		$sql = 'SELECT id FROM #__pf_form_fields WHERE form_id='.$row->id.' ORDER BY ordering' ;
		$db->setQuery($sql) ;
		$rowFields = $db->loadObjectList() ;
		$ordering = 0 ;				
		for ($i = 0 , $n = count($rowFields) ; $i < $n ; $i++) {
		    $ordering++ ;
		    $rowField = $rowFields[$i] ;
		    $sql = "UPDATE #__pf_form_fields SET `ordering`=$ordering WHERE id=".$rowField->id ;
		    $db->setQuery($sql) ;
		    $db->query() ;
		}
		JRequest::setVar('id', $row->id) ;
		return true;
	}
	/**
	 * Init campaign data
	 *
	 */
	function _initData() {
		$row = new stdClass ;		
		$row->id = 0;
		$row->title = "";
		$row->amount = "";
		$row->late_payment_date = "";
		$row->late_amount_type = 0 ;
		$row->late_payment_amount = "";
		$row->publish_up  = '' ;
		$row->publish_down = '' ;
		$row->end_date = "";
		$row->notification_emails = null ;
		$row->form_msg = null ;
		$row->confirmation_msg = null ;
		$row->thanks_message = null ;
		$row->cancel_message = null ;
		$row->notification_email_subject = null ;
		$row->notificaiton_email_body = null ;
		$row->confirmation_email_subject = null ;
		$row->confirmation_email_body = null ;
		$row->paypal_account = null ;
		$row->params = null ;
		$row->ordering = null ;
		$row->published = 1 ;	
		$row->access = 0 ;
		$row->enter_amount = 0 ;	
		$row->form_layout = null ;
		$row->enable_coupon = 0 ;
		$row->payment_methods = '' ;
		
		$this->_data = $row ;
	}
	/**
	 * Load campaign data
	 *
	 */
	function _loadData() {
		$sql = 'SELECT * FROM #__pf_forms WHERE id='.$this->_id;
		$this->_db->setQuery($sql);			
		$this->_data = $this->_db->loadObject();
	}
	/**
	 * Method to remove  campaigns
	 *
	 * @access	public
	 * @return	boolean	True on success
	 * @since	1.5
	 */
	function delete($cid = array())
	{		
		if (count( $cid ))
		{
			$cids =  implode(',', $cid);
			$sql = 'DELETE FROM #__pf_forms WHERE id IN ('.$cids.')';
			$this->_db->setQuery($sql);
			if (!$this->_db->query())
				return false;
            
			$sql = 'DELETE FROM #__pf_form_fields WHERE form_id IN('.$cids.')';
			$this->_db->setQuery($sql);
			$this->_db->query() ;												
		}
		return true;
	}
	/**
	 * Publish/Ubpublish forms
	 *
	 * @param int $id
	 * @param int $state
	 */
	function publish($cid, $state) {
		if (count($cid)) {
			$cids = implode(',', $cid) ;
			$sql = 'UPDATE #__pf_forms SET published='.$state. ' WHERE id IN('.$cids.')';
			$this->_db->setQuery($sql);
			$this->_db->query();
			return true ;	
		} else {
			return false ;	
		}				
	}	
	/**
	 * Save the order of forms
	 *
	 * @param array $cid
	 * @param array $order
	 */
	function saveOrder($cid, $order) {
		$row = JTable::getInstance('pmform', 'Form');				
		for( $i=0; $i < count($cid); $i++ )
		{
			$row->load( (int) $cid[$i] );						
			if ($row->ordering != $order[$i])
			{
				$row->ordering = $order[$i];
				if (!$row->store()) {
					$this->setError($this->_db->getErrorMsg());
					return false;
				}
			}
		}		
		return true;	
	}	
	/**
	 * Change ordering of a form
	 *
	 */
	function move($direction) {
		$row = JTable::getInstance('pmform', 'Form');
		$row->load($this->_id);		
		if (!$row->move( $direction, ' published >= 0 ' )) {
			$this->setError($this->_db->getErrorMsg());
			return false;
		}
		return true;
	}
	/**
	 * Copy a form	 
	 * @param int $id
	 */	
	function copy($id) {
		$rowOld = JTable::getInstance('pmform', 'Form');
		$rowOld->load($id) ;
		$row = JTable::getInstance('pmform', 'Form');
		$data = JArrayHelper::fromObject($rowOld) ; 
		$row->bind($data) ;
		$row->id = 0 ;
		$row->title = 'Copy of '.$row->title ;
		$row->store() ;
		$formId = $row->id ;
		$sql = "INSERT INTO #__pf_form_fields(form_id, field_id, published, ordering, required) 
				SELECT $formId, field_id, published, ordering, required FROM #__pf_form_fields WHERE form_id=$id
			   "				
		;
		$this->_db->setQuery($sql) ;
		$this->_db->query();
												
		return $row->id ;	
	}
}