<?php
/**
 * @version		3.0
 * @package		Joomla
 * @subpackage	Payment Form
 * @author  Tuan Pham Ngoc
 * @copyright	Copyright (C) 2010 Ossolution Team
 * @license		GNU/GPL, see LICENSE.php
 */
// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die ;
/**
 * Payment Form Component Payment Model
 *
 * @package		Joomla
 * @subpackage	Payment Form
 * @since 1.5
 */
class PmFormModelPayment extends JModelLegacy
{
	/**
	 * Donor id
	 *
	 * @var int
	 */
	var $_id = null;
	/**
	 * Donor data
	 *
	 * @var array
	 */
	var $_data = null;

	/**
	 * Constructor
	 *
	 * @since 1.5
	 */
	function __construct()
	{
		parent::__construct();
		$array = JRequest::getVar('cid', array(0), '', 'array');
		$edit	= JRequest::getVar('edit',true);
		if($edit)
			$this->setId((int)$array[0]);
	}
	/**
	 * Method to set the donor identifier
	 *
	 * @access	public
	 * @param	int donor identifier
	 */
	function setId($id)
	{
		// Set donor id and wipe data
		$this->_id		= $id;
		$this->_data	= null;
	}
	/**
	 *Get id of the donor
	 *
	 * @param int $id
	 */
	function getId() {
		return $this->_id ;
	}
	/**
	 * Method to get a donor
	 *
	 * @since 1.5
	 */
	function &getData()
	{
		if (empty($this->_data)) {
			if ($this->_id)
				$this->_loadData();
			else 
				$this->_initData();				
		}
		return $this->_data;
	}
	/**
	 * Method to store a donor
	 *
	 * @access	public
	 * @return	boolean	True on success
	 * @since	1.5
	 */
	function store(&$data)
	{		
		$config = PmFormHelper::getConfig() ;
		$row = & $this->getTable('PmForm', 'Payment');
		$published = true ;	
		if ($data['id']) {
			$row->load($data['id']);
			$published = $row->published ;
		}		
		if (!$row->bind($data)) {
			$this->setError($this->_db->getErrorMsg());
			return false;
		}		
		if (!$row->store()) {
			$this->setError($this->_db->getErrorMsg());
			return false;
		}				
		$paymentId = $row->id ;
		$jcFields = new JCFields($row->form_id) ;
		if ($jcFields->getTotal()) {
			$jcFields->saveFieldValues($paymentId) ;
		}
		if (!$published && $row->published) {
			//Send email to user to inform about changing payment status
			$this->_sendEmails($row, $config);			
		}
		return true;
	}
	/**
	 * Method to remove donors
	 *
	 * @access	public
	 * @return	boolean	True on success
	 * @since	1.5
	 */
	function delete($cid = array())
	{		
		if (count( $cid ))
		{
			$cids =  implode(',', $cid);
			//Delete from custom fields value
			$sql = 'DELETE FROM #__pf_field_value WHERE payment_id IN ('.$cids.')';
			$this->_db->setQuery($sql) ;
			$this->_db->query();
			$sql = 'DELETE FROM #__pf_payments WHERE id IN ('.$cids.')';
			$this->_db->setQuery($sql);
			if (!$this->_db->query())
				return false;			
		}
		return true;
	}		
	/**
	 * Load donor data from database
	 *
	 */
	function _loadData() {
		$sql = 'SELECT a.*, b.code AS coupon_code FROM #__pf_payments AS a ' 
		.' LEFT JOIN #__pf_coupons AS b '
		.' ON a.coupon_id = b.id '		
		.' WHERE a.id='.$this->_id;
		$this->_db->setQuery($sql);
		$this->_data = $this->_db->loadObject();				
	}
	/**
	 * Init donor data
	 *
	 */
	function _initData() {
		$row = JTable::getInstance('pmform', 'Payment') ;	
		$row->form_id = JRequest::getInt('form_id', 0) ;
		$this->_data = $row ;				
	}
	/**
	 * Publish donors
	 *
	 * @param array $cid
	 * @param int $state
	 */	
	function publish($cid, $state) {
		if ($state) {
			$row = JTable::getInstance('pmform', 'Payment') ;
			$config = PmFormHelper::getConfig() ;
			for ($i = 0 , $n = count($cid) ; $i < $n ; $i++) {
				$id = $cid[$i] ;
				$row->load($id);
				if (!$row->published) {
					$this->_sendEmails($row, $config);
				}
			}
			$sql = 'UPDATE #__pf_payments SET published='.$state.' WHERE id IN ('.implode(',', $cid).')';
			$this->_db->setQuery($sql) ;
			$this->_db->query();	
		} else {
			$sql = 'UPDATE #__pf_payments SET published='.$state.' WHERE id IN ('.implode(',', $cid).')';
			$this->_db->setQuery($sql) ;
			$this->_db->query();		
		}
		return true ;		
	}	
	/**
	 * Send notification emails to administrators and confirmation email to donor
	 *
	 * @param object $row
	 * @param object $config
	 */
	function _sendEmails($row, $config) {
		$mailer = JFactory::getMailer();
		$jconfig = new JConfig();		
		PmFormHelper::loadLanguage();
		$db = JFactory::getDBO();			
		$fromEmail =  $jconfig->mailfrom;
		$fromName = $jconfig->fromname;			
		$sql = "SELECT * FROM #__pf_forms WHERE id=".$row->form_id ;
		$db->setQuery($sql) ;
		$form = $db->loadObject();					
		//Need to over-ridde some config options				
		$emailContent = PmFormHelper::getEmailContent($config, $row);		
		$replaces = array() ;		
		$replaces['form_title'] = $form->title ;				
		$replaces['first_name'] = $row->first_name ;
		$replaces['last_name'] = $row->last_name ;
		$replaces['organization'] = $row->organization ;
		$replaces['address'] = $row->address ;
		$replaces['address2'] = $row->address ;
		$replaces['city'] = $row->city ;
		$replaces['state'] = $row->state ;
		$replaces['zip'] = $row->zip ;
		$replaces['country'] = $row->country ;
		$replaces['phone'] = $row->phone ;
		$replaces['fax'] = $row->phone ;
		$replaces['email'] = $row->email ;
		$replaces['comment'] = $row->comment ;
		$replaces['amount'] = number_format($row->amount, 2) ;		 
		//Should we create map to custom fields
		$sql = 'SELECT field_id, field_value FROM #__pf_field_value WHERE payment_id = '.$row->id;
		$db->setQuery($sql) ;
		$rowValues = $db->loadObjectList();
		$sql = 'SELECT a.id, a.name FROM #__pf_fields AS a INNER JOIN #__pf_form_fields AS b ON a.id = b.field_id WHERE a.published=1 AND b.published=1 AND a.is_core=0 AND b.form_id='.$row->form_id;
		$db->setQuery($sql) ;
		$rowFields = $db->loadObjectList();
		$fields = array() ;
		for ($i = 0 , $n = count($rowFields) ; $i < $n ; $i++) {
			$rowField = $rowFields[$i] ;
			$fields[$rowField->id] = $rowField->name ;			
		}	
		for ($i = 0 , $n = count($rowValues) ; $i < $n ; $i++) {
			$rowValue = $rowValues[$i] ;
			$replaces[$fields[$rowValue->field_id]] = $rowValue->field_value ;			
		}							
		//Notification email send to user
		$subject = $config->payment_approved_email_subject ;		
		$body = nl2br($config->payment_approved_email_body);				
		$subject = str_replace('[FORM_TITLE]', $form->title, $subject) ;
		$body = str_replace('[PAYMENT_DETAIL]', $emailContent, $body) ;
		foreach ($replaces as $key=>$value) {
			$key = strtoupper($key) ;
			$body = str_replace("[$key]", $value, $body) ;
		}				
		$mailer->sendMail($fromEmail, $fromName, $row->email, $subject, $body, 1);																										
	}			
}