<?php
/**
 * @version		3.0
 * @package		Joomla
 * @subpackage	Payment Form
 * @author  Tuan Pham Ngoc
 * @copyright	Copyright (C) 2010 Ossolution Team
 * @license		GNU/GPL, see LICENSE.php
 */
// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die ;
/**
 * Payment Form Component Payment Model
 *
 * @package		Joomla
 * @subpackage	Payment Form
 * @since 1.5
 */
class PmFormModelPayments extends JModelLegacy
{
	/**
	 * Payments data array
	 *
	 * @var array
	 */
	var $_data = null;

	/**
	 * Payments total
	 *
	 * @var integer
	 */
	var $_total = null;

	/**
	 * Pagination object
	 *
	 * @var object
	 */
	var $_pagination = null;

	/**
	 * Constructor
	 *
	 * @since 1.5
	 */
	function __construct()
	{
		parent::__construct();

		$mainframe = JFactory::getApplication() ;
		$option    = 'com_pmform' ;    

		// Get the pagination request variables
		$limit		= $mainframe->getUserStateFromRequest( 'global.list.limit', 'limit', $mainframe->getCfg('list_limit'), 'int' );
		$limitstart	= $mainframe->getUserStateFromRequest( $option.'.limitstart', 'limitstart', 0, 'int' );

		// In case limit has been changed, adjust limitstart accordingly
		$limitstart = ($limit != 0 ? (floor($limitstart / $limit) * $limit) : 0);

		$this->setState('limit', $limit);
		$this->setState('limitstart', $limitstart);
	}

	/**
	 * Method to get donors data
	 *
	 * @access public
	 * @return array
	 */
	function getData()
	{
		// Lets load the content if it doesn't already exist
		if (empty($this->_data))
		{
			$query = $this->_buildQuery();
			$this->_data = $this->_getList($query, $this->getState('limitstart'), $this->getState('limit'));			
		}

		return $this->_data;
	}

	/**
	 * Method to get the total number of donors
	 *
	 * @access public
	 * @return integer
	 */
	function getTotal()
	{
		// Lets load the content if it doesn't already exist
		if (empty($this->_total))
		{
			$where = $this->_buildContentWhere();
			$sql  = 'SELECT COUNT(*) FROM #__pf_payments AS a '.$where ;
			$this->_db->setQuery($sql);
			$this->_total = $this->_db->loadResult();
		}
		return $this->_total;
	}
	/**
	 * Method to get a pagination object for the payments
	 *
	 * @access public
	 * @return integer
	 */
	function getPagination()
	{
		// Lets load the content if it doesn't already exist
		if (empty($this->_pagination))
		{
			jimport('joomla.html.pagination');
			$this->_pagination = new JPagination( $this->getTotal(), $this->getState('limitstart'), $this->getState('limit') );
		}

		return $this->_pagination;
	}
	/**
	 * Build the select clause
	 *
	 * @return string
	 */
	function _buildQuery()
	{
		// Get the WHERE and ORDER BY clauses for the query
		$where		= $this->_buildContentWhere();
		$orderby	= $this->_buildContentOrderBy();
		
		$showCoupon = (int)PmFormHelper::getConfigValue('show_coupon');
		if ($showCoupon) {
			$query = 'SELECT a.*, b.title, c.username, d.code AS coupon_code  FROM #__pf_payments AS a '
			. ' INNER JOIN #__pf_forms AS b '
			. ' ON a.form_id = b.id '
			. ' LEFT JOIN #__users AS c '
			. ' ON a.user_id = c.id '
			. ' LEFT JOIN #__pf_coupons AS d '
			. ' ON a.coupon_id = d.id '
			
			. $where
			. $orderby
			;
		} else {
			$query = 'SELECT a.*, b.title, c.username  FROM #__pf_payments AS a '
			. ' INNER JOIN #__pf_forms AS b '
			. ' ON a.form_id = b.id '
			. ' LEFT JOIN #__users AS c '
			. ' ON a.user_id = c.id '
			. $where
			. $orderby
			;
		}				
				
		return $query;
	}
	/**
	 * Build order by clause for the select command
	 *
	 * @return string order by clause
	 */
	function _buildContentOrderBy()
	{
		$mainframe          = JFactory::getApplication() ;
		$option             = 'com_pmform' ;    
		$filter_order		= $mainframe->getUserStateFromRequest( $option.'.payments.filter_order',		'filter_order',		'a.created_date',	'cmd' );		
		$filter_order_Dir	= $mainframe->getUserStateFromRequest( $option.'filter_order_Dir',	'filter_order_Dir',	'DESC',				'word' );		
		$orderby = ' ORDER BY '.$filter_order.' '.$filter_order_Dir;		
		
		return $orderby;
	}
	/**
	 * Build the where clause
	 *
	 * @return string
	 */
	function _buildContentWhere()
	{
		$mainframe          = JFactory::getApplication() ;
		$option             = 'com_pmform' ; 
		$db					= JFactory::getDBO();		
		$search				= $mainframe->getUserStateFromRequest( $option.'search',			'search',			'',				'string' );		
		$search				= JString::strtolower( $search );
		$formId 		= $mainframe->getUserStateFromRequest( $option.'form_id',			'form_id',			0,				'int' );
		$where = array();
		$where[] = ' (a.published=1 OR a.payment_method = "os_offline")';		
		if ($formId) {
			$where[] = ' a.form_id='.$formId;
		}
		if ($search) {
			$where[] = 'LOWER(a.first_name) LIKE '.$db->Quote( '%'.$db->getEscaped( $search, true ).'%', false ).' OR LOWER(a.last_name) LIKE '.$db->Quote( '%'.$db->getEscaped( $search, true ).'%', false );
		}						
		$where 		= ( count( $where ) ? ' WHERE '. implode( ' AND ', $where ) : '' );
		return $where;
	}	
}