<?php
/**
 * @copyright	Copyright (C) 2012 Daniel Calviño Sánchez
 * @license		GNU Affero General Public License version 3 or later; see LICENSE.txt
 */

defined('_JEXEC') or die;

jimport('joomla.application.component.modellist');

/**
 * Model for the manager of the routes.
 * It uses Joomla infrastructure.
 */
class ProductSearchModelRoutes extends JModelList {

    /**
     * Creates a new SimpleCustomRouterModelRoutes.
     * The id, path and query are set as filter fields (so the list can be
     * ordered by those fields in the view).
     * 
	 * @param array $config An optional associative array of configuration
	 *        settings.
     */
    public function __construct($config = array()) {
        if (empty($config['filter_fields'])) {
            $config['filter_fields'] = array(
                's.id',
                's.path',
                's.query',
				'i.name'
            );
        }

        parent::__construct($config);
    }
    /**
	 * Method to auto-populate the model state.
	 *
	 * Note. Calling getState in this method will result in recursion.
	 */
	protected function populateState($ordering = null, $direction = null)
	{
		// Initialise variables.
		$app = JFactory::getApplication('administrator');

		// Load the filter state.
		$search = $app->getUserStateFromRequest($this->context.'.filter.search', 'filter_search');
		$this->setState('filter.search', $search);
        // Load the parameters.
		$params = JComponentHelper::getParams('com_productsearch');
		$this->setState('params', $params);
		// List state information.
		parent::populateState('s.id', 'asc');
	}
	/**
	 * Method to get a store id based on model configuration state.
	 *
	 * This is necessary because the model is used by the component and
	 * different modules that might need different sets of data or different
	 * ordering requirements.
	 *
	 * @param	string		$id	A prefix for the store id.
	 * @return	string		A store id.
	 * @since	1.6
	 */
	protected function getStoreId($id = '')
	{
		// Compile the store id.
		$id.= ':' . $this->getState('filter.search');
		return parent::getStoreId($id);
	}
    /**
	 * Implementation of JModelList::getListQuery to get a JDatabaseQuery object
	 * for retrieving the data set from a database.
	 * The query selects all the fields from #__simplecustomrouter, ordered by
	 * the column and direction set in the state by the parent model.
	 *
	 * @return JDatabaseQuery A JDatabaseQuery object to retrieve the data set.
     */
    protected function getListQuery() {
        $db = JFactory::getDBO();
        $query = $db->getQuery(true);

        $query->select('s.id,s.path,s.query,s.itemId,s.product_id');
        $query->from('#__simplecustomrouter AS s');
		
		$query->select('i.name as product_name');
        $query->join('left','#__djc2_items AS i ON i.id = s.product_id');
		
		// Filter by search in title
		$search = $this->getState('filter.search');
		if (!empty($search)) {
			if (stripos($search, 'id:') === 0) {
				$query->where('s.id = '.(int) substr($search, 3));
			} else {
				$search = $db->Quote('%'.$db->escape($search, true).'%');
                $query->where('( i.name LIKE '.$search.' )');
			}
		}
		
        $orderColumn = $this->state->get('list.ordering', 's.id');
        $orderDirection = $this->state->get('list.direction', 'ASC');
		if ($orderColumn && $orderDirection) {
            $query->order($orderColumn.' '.$orderDirection);
        }
        return $query;
    }
}
