<?php
/**
 * SocialBacklinks Requirements helper
 *
 * We developed this code with our hearts and passion.
 * We hope you found it useful, easy to understand and change.
 * Otherwise, please feel free to contact us at contact@joomunited.com
 *
 * @package 	Social Backlinks
 * @copyright 	Copyright (C) 2012 JoomUnited (http://www.joomunited.com). All rights reserved.
 * @license 	GNU General Public License version 2 or later; http://www.gnu.org/licenses/gpl-2.0.html
 */

/**
 * SocialBacklinks Back-End Controller's helper for syncronizing
 * @static
 */
class SBHelpersSync extends JObject
{
	/**
	 * Stores last sync date object
	 * @var JDate
	 */
	private static $_last_sync = null;
	
	/**
	 * Stores identifiers of last records
	 * @var array
	 */
	private static $_last_ids = array( 'history' => -1, 'error' => -1 );
	
	/**
	 * Checks periodicity of the synchronization articles with social networks
	 * @return boolean
	 */
	public static function isNeedSync( )
	{
		if ( !$last_sync = self::getLastSyncDate( ) ) {
			return true;
		}

		if ( !$item = JModel::getInstance( 'SBModelsConfig' )->reset( )->section( 'basic' )->name( 'sync_periodicity' )->getItem( ) ) {
			$period = 5;
		}
		else {
			$period = (int)$item->value;
		}

		$date = self::convertDate( );

		$date_diff = ($date->toUnix( ) - $last_sync->toUnix( )) / 60;
		return ($date_diff >= $period);
	}

	/**
	 * Converts date to date according current timezone
	 * @param  string. If null, the function will return current date
	 * @return JDate
	 */
	public static function convertDate( $date = 'now' )
	{
		$config = JFactory::getConfig( );
		$tz = $config->getValue( 'config.offset' );
		$tz_object = new DateTimeZone( $tz);
		
		$result = JFactory::getDate( $date );
		$result->setTimezone( $tz_object );
		
		return $result;
	}
	
	/**
	 * Returns the last sync date
	 * @return date|null
	 */
	public static function getLastSyncDate( )
	{
		if ( !self::$_last_sync && ($config = JModel::getInstance( 'SBModelsConfig' )->reset( )->section( 'basic' )->name( 'last_sync' )->getItem( )) ) {
			self::$_last_sync = self::convertDate( $config->value );
		}
		return self::$_last_sync;
	}

	/**
	 * Updates the date of last synchronizing
	 * @return void
	 */
	public static function updateLastSyncDate( )
	{
		$db = JFactory::getDbo( );
		$params = array(
			'section' => 'basic',
			'name' => 'last_sync',
			'value' => $db->escape( self::convertDate( )->toSql() )
		);
		JModel::getInstance( 'SBModelsConfig' )->reset( )->setData( $params )->update( );
	}

	/**
	 * Returns the last identifier of history or errors
	 * @param 	string 	The type of id
	 * @param 	boolean Shows must we use db connection or not
	 * @return 	integer
	 */
	public static function getLastId( $type = 'history', $use_db = true )
	{
		if ( !key_exists($type, self::$_last_ids) ) {
			throw new SBException( JText::sprintf( 'SB_NO_VALID_PARAM', $type, __FUNCTION__ ) );
		}
		if ( $use_db ) {
			$result = 0;
			if ( $type == 'error' ) {
				$model = JModel::getInstance( 'SBModelsErrors' );
				//TODO It doesn't work for errors. Should it?
				$select = 'MAX(socialbacklinks_error_id)';
			}
			else {
				$model = JModel::getInstance( 'SBModelsHistories' );
				$select = 'MAX(socialbacklinks_history_id)';
			}
			$model->reset( )->select( $select . ' FROM ' . $model->getTable( )->getTableName( ) );
	
			if ( $list = $model->getList( ) ) {
				$res = (array) current( $list );
				if ( $res = current( $res ) ) {
					$result = (int) $res;
				}
			}
		}
		else {
			$result = self::$_last_ids[$type];
		}
		return $result;
	}
	
	/**
	 * Saves identifier of last record before add new record
	 * @param string $type Type of the identifier
	 * @return void
	 */
	public static function setLastId( $type = 'history' )
	{
		if ( !key_exists($type, self::$_last_ids) ) {
			throw new SBException( JText::sprintf( 'SB_NO_VALID_PARAM', $type, __FUNCTION__ ) );
		}
		
		if ( self::$_last_ids[$type] < 0 ) {
			self::$_last_ids[$type] = self::getLastId( $type );
		}
	}

	/**
	 * Checks if there were any error
	 * @return boolean
	 */
	public static function hasError()
	{
		return ( self::$_last_ids['error'] >= 0 );
	}
	
	/**
	 * Formats data of the item
	 * @param  SBPluginsContentsInterface The content plugin object
	 * @param  JObject Item data
	 * @return JObject
	 */
	public static function formatData( SBPluginsContentsInterface $plugin, $row )
	{
		$item = new JObject( );
		$sync_updated = (bool)$plugin->sync_updated;
		$is_new = true;
		$db = JFactory::getDBO( );

		// Checks whether item is new record
		$nulldate = $db->Quote( $db->getNullDate( ) );
		if ( $sync_updated && ($row->modified != $nulldate) ) {
			$created = self::convertDate( $row->created );
			$modified = self::convertDate( $row->modified );
			$sec_in_day = 3600 * 24;

			$date_diff = ($modified->toUnix( ) - $created->toUnix( )) / $sec_in_day;
			$is_new = false;
			if ( !self::_getBasicParam( 'clean_history' ) || ($date_diff < (int)self::_getBasicParam( 'clean_history_periodicity', 30 )) ) {
				if ( !JModel::getInstance( 'SBModelsHistories' )->reset( )->extension( $plugin->getAlias( ) )->item_id( $row->id )->result( 1 )->getItem( ) ) {
					$is_new = true;
				}
			}
		}

		// Creates title of the item
		$title_suffix = '';
		if ( !$is_new ) {
			$date = SBHelpersSync::convertDate( $row->modified )->format( 'M d, Y H:i', true );
			$title_suffix = ' (' . JText::sprintf( 'SB_CONTENT_UPDATED', $date ) . ')';
		}
		
		$max_title_length = 115;
		$title = $row->title;
		if ( strlen( $title ) + strlen( $title_suffix ) > $max_title_length )
		{
			$title_length = $max_title_length - strlen( $title_suffix ) - 3;
			$buff = strpos( wordwrap( $title, $title_length, '^~^', true ), '^~^' );
			$title = substr( $title, 0, $buff ) . '...';
		}
		$item->title = $title . $title_suffix;		
		
		$item->link = self::_getLink( $plugin, $row );

		// Creates description of the element
		if ( $plugin->sync_desc ) {
			$desc = wordwrap( strip_tags( $row->introtext ), 200, '^~^' );
			$buff = strpos( $desc, '^~^' );

			if ( $buff ) {
				$desc = substr( $desc, 0, $buff ) . '...';
			}
			$item->desc = $desc;
 		}
		else {
			$item->desc = '';
		}

		return $item;
	}

	/**
	 * Returns basic config parameter
	 * @param  string Parameter to be returned
	 * @param  mixed  Default value
	 * @return mixed
	 */
	protected static function _getBasicParam( $param, $default = null )
	{
		if ( $config = JModel::getInstance( 'SBModelsConfig' )->reset( )->section( 'basic' )->name( $param )->getItem( ) ) {
			return $config->value;
		}
		return $default;
	}

	/**
	 * Returns the link to the article
	 * @param  SBPluginsContentsInterface $plugin
	 * @param  JObject $article
	 * @return string
	 */
	protected static function _getLink( SBPluginsContentsInterface $plugin, $item )
	{
		// In the back end we need to set the application to the site app instead
		if ( JPATH_BASE != JPATH_SITE ) {
			$app = &JFactory::$application;
			$site_app = JApplication::getInstance( 'site' );
			$admin_app = clone $app;
			$app = $site_app;
		}
		$link = JRoute::_( $plugin->getItemRoute( $item ), false, 2 );

		// Set the appilcation back to the administartor app
		if ( JPATH_BASE != JPATH_SITE ) {
			$link = str_replace( '/administrator/', '/', $link );
			$app = $admin_app;
		}
		return $link;
	}
	
	/**
	 * Deletes old history records
	 * @return void
	 */
	public static function cleanHistory()
	{
		if ( !($item = JModel::getInstance( 'SBModelsConfig' )->reset( )->section( 'basic' )->name( 'clean_history' )->getItem( )) || !($item->value) ) {
			return true;
		}

		if ( !$item = JModel::getInstance( 'SBModelsConfig' )->reset( )->section( 'basic' )->name( 'clean_history_periodicity' )->getItem( ) ) {
			$period = 30;
		}
		else {
			$period = (int)$item->value;
		}
		JModel::getInstance( 'SBModelsHistories' )->setData( 'periodicity', $period )->delete( );
	}
	
	/**
	 * Sends email message about errors
	 * @return boolean
	 */
	public static function sendErrorEmail()
	{
		// Get statistics information after last record
		$rows = array();
		if ( self::getLastId( 'error', false ) >= 0 ) {
			$model = JModel::getInstance( 'SBModelsErrors' );
			foreach (SBPlugin::get('content.') as $content) {
				if ( $new_rows = $model->reset()->last_id( self::getLastId( 'error', false ) )->plugin( $content )->getList() ) {
					$rows = array_merge( $rows, $new_rows );
				}
			}
		}
		
		$success = true;
		if ( !empty($rows) ) {
			$config = JFactory::getConfig( );
			// send mail to users
			$type = SBHelpersConfig::getProperty( 'errors_recipient_type', 'basic', 0 );
			
			if ( $type == 1 ) {
				$username = JText::_( 'SB_ADMINISTRATOR' );
	
				$sitename = $config->getValue( 'config.sitename' );
				$siteurl = JURI::root( );
				$siteadmin_link_start = '<a href="' . $siteurl . 'administrator/" target="_blank">';
				$siteadmin_link_end = '</a>';
	
				$html = '';
				ob_start( );
				// need such values: $username, $rows, $sitename, $siteurl, $siteadmin_link_start, $siteadmin_link_end
				require_once JPATH_ROOT . '/administrator/components/com_socialbacklinks/views/errors/tmpl/mail.php';
				$html = ob_get_contents( );
				ob_clean( );
	
				$subject = JText::sprintf( 'SB_ERRORS_EMAIL_SUBJECT', $sitename );
	
				$send_errors_email = SBHelpersConfig::getProperty( 'send_errors_email' );
				if ( is_null( $send_errors_email ) ) {
					return true;
				}

				$success = JUtility::sendMail( $config->getValue( 'config.mailfrom' ), $config->getValue( 'config.fromname' ), $send_errors_email, $subject, $html, true );
			}
			elseif ( $type == 2 ) {
				$sitename = $config->getValue( 'config.sitename' );
				$siteurl = JURI::root( );
				$siteadmin_link_start = '<a href="' . $siteurl . 'administrator/" target="_blank">';
				$siteadmin_link_end = '</a>';
	
				$subject = JText::sprintf( 'SB_ERRORS_EMAIL_SUBJECT', $sitename );
	
				$users = SBHelpersUser::getSuperAdministrators( );
	
				foreach ($users as $user) {
					if ( !$user->sendEmail ) {
						continue;
					}
					$username = $user->name;
	
					$html = '';
					ob_start( );
					// need such values: $username, $rows, $sitename, $siteurl, $siteadmin_link_start, $siteadmin_link_end
					require_once JPATH_ROOT . '/administrator/components/com_socialbacklinks/views/errors/tmpl/mail.php';
					$html = ob_get_contents( );
					ob_clean( );
	
					if ( !JUtility::sendMail( $config->getValue( 'config.mailfrom' ), $config->getValue( 'config.fromname' ), $user->email, $subject, $html, true ) ) {
						$success = false;
					}
				}
			}
		}
		return $success;
	}

}
